==> kdelibs-3.5.0.tar.bz2: kdelibs-3.5.0/kdecore/kconfig_compiler/tests/test9main.cpp <==
/*
Copyright (c) 2005 Helge Deller <deller@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#include "test9.h"
#include "kinstance.h"
#include <kdebug.h>
#include <qdir.h>

int main( int, char )
{
  KInstance i("test");
  Test9 *t = new Test9( QString::null, QString::null );

  QStringList myPathsList2 = t->myPathsList2();
  kdWarning() << myPathsList2 << endl;

  // add another path
  QStringList newlist = QDir::homeDirPath() + QString::fromLatin1("/.kde");
  myPathsList2 = myPathsList2 + newlist;
  kdWarning() << myPathsList2 << endl;

  t->setMyPathsList2(myPathsList2);
  kdWarning() << t->myPathsList2() << endl;

  delete t;
}

==> kdelibs-3.5.9.tar.bz2: kdelibs-3.5.9/kdecore/kconfig_compiler/tests/test9main.cpp <==
/*
Copyright (c) 2005 Helge Deller <deller@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#include "test9.h"
#include "kinstance.h"
#include <kdebug.h>
#include <qdir.h>

int main( int, char*[] )
{
  KInstance i("test");
  Test9 *t = new Test9( QString::null, QString::null );

  QStringList myPathsList2 = t->myPathsList2();
  kdWarning() << myPathsList2 << endl;

  // add another path
  QStringList newlist = QDir::homeDirPath() + QString::fromLatin1("/.kde");
  myPathsList2 = myPathsList2 + newlist;
  kdWarning() << myPathsList2 << endl;

  t->setMyPathsList2(myPathsList2);
  kdWarning() << t->myPathsList2() << endl;

  delete t;
}
